Class: AgentCatApi::EventsApi
- Inherits:
-
Object
- Object
- AgentCatApi::EventsApi
- Defined in:
- lib/agentcat-api/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ EventsApi
constructor
A new instance of EventsApi.
-
#publish_event(opts = {}) ⇒ EventAcceptedResponse
Publish analytics event Submit analytics events for a project.
-
#publish_event_with_http_info(opts = {}) ⇒ Array<(EventAcceptedResponse, Integer, Hash)>
Publish analytics event Submit analytics events for a project.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/agentcat-api/api/events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#publish_event(opts = {}) ⇒ EventAcceptedResponse
Publish analytics event Submit analytics events for a project. Returns immediately with 202 Accepted.
27 28 29 30 |
# File 'lib/agentcat-api/api/events_api.rb', line 27 def publish_event(opts = {}) data, _status_code, _headers = publish_event_with_http_info(opts) data end |
#publish_event_with_http_info(opts = {}) ⇒ Array<(EventAcceptedResponse, Integer, Hash)>
Publish analytics event Submit analytics events for a project. Returns immediately with 202 Accepted.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/agentcat-api/api/events_api.rb', line 37 def publish_event_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.publish_event ...' end # resource path local_var_path = '/v1/public/events/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'publish_event_request']) # return_type return_type = opts[:debug_return_type] || 'EventAcceptedResponse' # auth_names auth_names = opts[:debug_auth_names] || ['tokenAuth'] = opts.merge( :operation => :"EventsApi.publish_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#publish_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |