Class: AgentCatApi::NotificationsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/agentcat-api/api/notifications_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ NotificationsApi

Returns a new instance of NotificationsApi.



19
20
21
# File 'lib/agentcat-api/api/notifications_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/agentcat-api/api/notifications_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#unsubscribe_notification(opts = {}) ⇒ String

Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST. The token encodes the user and the notification type to disable. Response bodies are plain text.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :token (String)

    Signed unsubscribe token. May also be passed in the request body.

  • :unsubscribe_request_request (UnsubscribeRequestRequest)

Returns:

  • (String)


28
29
30
31
# File 'lib/agentcat-api/api/notifications_api.rb', line 28

def unsubscribe_notification(opts = {})
  data, _status_code, _headers = unsubscribe_notification_with_http_info(opts)
  data
end

#unsubscribe_notification_with_http_info(opts = {}) ⇒ Array<(String, Integer, Hash)>

Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST. The token encodes the user and the notification type to disable. Response bodies are plain text.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :token (String)

    Signed unsubscribe token. May also be passed in the request body.

  • :unsubscribe_request_request (UnsubscribeRequestRequest)

Returns:

  • (Array<(String, Integer, Hash)>)

    String data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/agentcat-api/api/notifications_api.rb', line 39

def unsubscribe_notification_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: NotificationsApi.unsubscribe_notification ...'
  end
  # resource path
  local_var_path = '/v1/public/notifications/unsubscribe'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'unsubscribe_request_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'String'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"NotificationsApi.unsubscribe_notification",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: NotificationsApi#unsubscribe_notification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end