Class: AgentCatApi::NotificationsApi
- Inherits:
-
Object
- Object
- AgentCatApi::NotificationsApi
- Defined in:
- lib/agentcat-api/api/notifications_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ NotificationsApi
constructor
A new instance of NotificationsApi.
-
#unsubscribe_notification(opts = {}) ⇒ String
Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST.
-
#unsubscribe_notification_with_http_info(opts = {}) ⇒ Array<(String, Integer, Hash)>
Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST.
-
#verify_email_channel(opts = {}) ⇒ EmailChannelVerifyResponse
Activate an email channel from its verification link.
-
#verify_email_channel_with_http_info(opts = {}) ⇒ Array<(EmailChannelVerifyResponse, Integer, Hash)>
Activate an email channel from its verification link.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ NotificationsApi
Returns a new instance of NotificationsApi.
19 20 21 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#unsubscribe_notification(opts = {}) ⇒ String
Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST. The token encodes the user and the notification type to disable. Response bodies are plain text.
28 29 30 31 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 28 def unsubscribe_notification(opts = {}) data, _status_code, _headers = unsubscribe_notification_with_http_info(opts) data end |
#unsubscribe_notification_with_http_info(opts = {}) ⇒ Array<(String, Integer, Hash)>
Disable an email notification type for the token's user Anonymous endpoint reached from email unsubscribe links and the List-Unsubscribe header POST. The token encodes the user and the notification type to disable. Response bodies are plain text.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 39 def unsubscribe_notification_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NotificationsApi.unsubscribe_notification ...' end # resource path local_var_path = '/v1/public/notifications/unsubscribe' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'unsubscribe_request_request']) # return_type return_type = opts[:debug_return_type] || 'String' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"NotificationsApi.unsubscribe_notification", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NotificationsApi#unsubscribe_notification\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_email_channel(opts = {}) ⇒ EmailChannelVerifyResponse
Activate an email channel from its verification link
94 95 96 97 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 94 def verify_email_channel(opts = {}) data, _status_code, _headers = verify_email_channel_with_http_info(opts) data end |
#verify_email_channel_with_http_info(opts = {}) ⇒ Array<(EmailChannelVerifyResponse, Integer, Hash)>
Activate an email channel from its verification link
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/agentcat-api/api/notifications_api.rb', line 104 def verify_email_channel_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: NotificationsApi.verify_email_channel ...' end # resource path local_var_path = '/v1/public/notifications/channels/verify' # query parameters query_params = opts[:query_params] || {} query_params[:'token'] = opts[:'token'] if !opts[:'token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'email_channel_verify_request']) # return_type return_type = opts[:debug_return_type] || 'EmailChannelVerifyResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"NotificationsApi.verify_email_channel", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: NotificationsApi#verify_email_channel\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |